@@ -22,6 +22,10 @@ where
     /// `I::default()`.
     ///
     /// The vector is initialized with `vec![I::default(); len]`.
+    ///
+    /// # Panics
+    ///
+    /// Vector initialization may panic if `len` is too big.
     pub fn with_len(len: usize) -> Self {
         Self {
             tree: vec![I::default(); len],
@@ -33,46 +37,41 @@ where
         self.tree.len()
     }
 
-    /// A partial sum of the specified range.
+    /// A partial sum of the specified `bounds`.
     ///
     /// Complexity: _O_(log _n_).
+    ///
+    /// Note that `sum` for empty range (a range `(i..j)` where `i >= j`) is `0`.
+    ///
+    /// Also, `bounds` are converted into a pair `(start, end)` that represents `[start,
+    /// end)` range. This means that boundary case `tree.sum(i..=usize::MAX)` fallbacks to `tree.sum(0..usize::MAX)`.
+    /// However, in practice, it's not possible to construct such a big tree ([`Vec`] panics with
+    /// `capacity overflow`).
     pub fn sum(&self, bounds: impl RangeBounds<usize>) -> Result<I, SumError> {
         let len = self.len();
 
-        let mut s = I::default();
-        let mut i = start(bounds.start_bound());
-        let mut j = end(bounds.end_bound(), len);
+        let mut sum = I::default();
+        let mut start = start(bounds.start_bound());
+        let mut end = end(bounds.end_bound(), len);
 
-        if i == j {
-            return Err(SumError::RangeEmpty {
-                bounds: as_pair(bounds),
-            });
-        }
-
-        if i > j {
-            return Err(SumError::RangeDecreasing {
-                bounds: as_pair(bounds),
-            });
-        }
-
-        if i >= len || j > len {
-            return Err(SumError::RangeOutside {
+        if start >= len || end > len {
+            return Err(SumError::OutOfRange {
                 bounds: as_pair(bounds),
                 len,
             });
         }
 
-        while j > i {
-            s += self.tree[j - 1];
-            j = prev(j);
+        while end > start {
+            sum += self.tree[end - 1];
+            end = prev(end);
         }
 
-        while i > j {
-            s -= self.tree[i - 1];
-            i = prev(i);
+        while start > end {
+            sum -= self.tree[start - 1];
+            start = prev(start);
         }
 
-        return Ok(s);
+        return Ok(sum);
 
         // As inclusive.
         fn start(bound: Bound<&usize>) -> usize {
@@ -87,7 +86,7 @@ where
         // As exclusive.
         fn end(bound: Bound<&usize>, len: usize) -> usize {
             match bound {
-                Bound::Included(0) => 0,
+                Bound::Included(&usize::MAX) => usize::MAX,
                 Bound::Included(x) => *x + 1,
                 Bound::Excluded(x) => *x,
                 Bound::Unbounded => len,
@@ -100,6 +99,7 @@ where
 
             return (start, end);
 
+            // From nightly Rust (https://doc.rust-lang.org/std/ops/enum.Bound.html#method.cloned).
             fn cloned(x: Bound<&usize>) -> Bound<usize> {
                 match x {
                     Bound::Unbounded => Bound::Unbounded,
